@@ -1,6 +1,7 @@
 """This module creates the database."""
 from os import environ
 from typing import Optional, Dict, List, Any
+from enum import Enum
 import logging
 import sys
 import atexit
@@ -16,6 +17,42 @@ logger = logging.getLogger("therapy")
 logger.setLevel(logging.DEBUG)
 
 
+# can be set to either `Dev`, `Staging`, or `Prod`
+# ONLY set when wanting to access aws instance
+AWS_ENV_VAR_NAME = "THERAPY_NORM_ENV"
+
+# Set to "true" if want to skip db confirmation check. Should ONLY be used for
+# deployment needs
+SKIP_AWS_DB_ENV_NAME = "SKIP_AWS_CONFIRMATION"
+
+
+class AwsEnvName(str, Enum):
+    """AWS environment name that is being used"""
+
+    DEVELOPMENT = "Dev"
+    STAGING = "Staging"
+    PRODUCTION = "Prod"
+
+
+VALID_AWS_ENV_NAMES = {v.value for v in AwsEnvName.__members__.values()}
+
+
+class DatabaseException(Exception):
+    """Create custom class for handling database exceptions"""
+
+    pass
+
+
+def confirm_aws_db_use(env_name: str) -> None:
+    """Check to ensure that AWS instance should actually be used."""
+    if click.confirm(f"Are you sure you want to use the AWS {env_name} database?",
+                     default=False):
+        click.echo(f"***THERAPY AWS {env_name.upper()} DATABASE IN USE***")
+    else:
+        click.echo("Exiting.")
+        sys.exit()
+
+
 class Database:
     """The database class."""
 
@@ -25,24 +62,26 @@ class Database:
         :param str db_url: database endpoint URL to connect to
         :param str region_name: AWS region name to use
         """
-        if "THERAPY_NORM_PROD" in environ or "THERAPY_NORM_EB_PROD" in environ:
+        therapy_concepts_table = "therapy_concepts"  # default
+        therapy_metadata_table = "therapy_metadata"  # default
+
+        if AWS_ENV_VAR_NAME in environ:
+            aws_env = environ[AWS_ENV_VAR_NAME]
+            if aws_env not in VALID_AWS_ENV_NAMES:
+                raise DatabaseException(f"{AWS_ENV_VAR_NAME} must be one of {VALID_AWS_ENV_NAMES}")  # noqa: E501
+
+            skip_confirmation = environ.get(SKIP_AWS_DB_ENV_NAME)
+            if (not skip_confirmation) or (skip_confirmation and skip_confirmation != "true"):  # noqa: E501
+                confirm_aws_db_use(environ[AWS_ENV_VAR_NAME])
+
             boto_params = {
                 "region_name": region_name
             }
+
+            if aws_env == AwsEnvName.DEVELOPMENT:
+                therapy_concepts_table = "therapy_concepts_nonprod"
+                therapy_metadata_table = "therapy_metadata_nonprod"
             self.endpoint_url = ""
-            if "THERAPY_NORM_PROD" in environ:
-                environ["DISEASE_NORM_PROD"] = "true"
-            if "THERAPY_NORM_EB_PROD" in environ:
-                environ["DISEASE_NORM_EB_PROD"] = "true"
-            else:
-                # EB Instance should not have to confirm.
-                # This is used only for using production via CLI
-                if click.confirm("Are you sure you want to use the "
-                                 "production database?", default=False):
-                    click.echo("***THERAPY PRODUCTION DATABASE IN USE***")
-                else:
-                    click.echo("Exiting.")
-                    sys.exit()
         else:
             if db_url:
                 self.endpoint_url = db_url
@@ -50,8 +89,7 @@ class Database:
                 self.endpoint_url = environ["THERAPY_NORM_DB_URL"]
             else:
                 self.endpoint_url = "http://localhost:8000"
-            click.echo(f"***Using Therapy Database Endpoint: "
-                       f"{self.endpoint_url}***")
+            click.echo(f"***Using Therapy Database Endpoint: {self.endpoint_url}***")
             environ["DISEASE_NORM_DB_URL"] = self.endpoint_url
 
             boto_params = {
@@ -62,15 +100,14 @@ class Database:
         self.dynamodb = boto3.resource("dynamodb", **boto_params)
         self.dynamodb_client = boto3.client("dynamodb", **boto_params)
 
-        # Table creation for local database
-        if "THERAPY_NORM_PROD" not in environ and \
-                "THERAPY_NORM_EB_PROD" not in environ:
+        # Only create tables for local instance
+        if not {AWS_ENV_VAR_NAME} & set(environ):
             existing_tables = self.dynamodb_client.list_tables()["TableNames"]
             self.create_therapies_table(existing_tables)
             self.create_meta_data_table(existing_tables)
 
-        self.therapies = self.dynamodb.Table("therapy_concepts")
-        self.metadata = self.dynamodb.Table("therapy_metadata")
+        self.therapies = self.dynamodb.Table(therapy_concepts_table)
+        self.metadata = self.dynamodb.Table(therapy_metadata_table)
         self.batch = self.therapies.batch_writer()
         self.cached_sources: Dict[str, Any] = {}
         atexit.register(self.flush_batch)
