@@ -4,9 +4,8 @@ from enum import Enum, IntEnum
 from datetime import datetime
 
 from ga4gh.vrsatile.pydantic import return_value
-from ga4gh.vrsatile.pydantic.core_models import CURIE
-from ga4gh.vrsatile.pydantic.vrsatile_models import DiseaseDescriptor, \
-    ValueObjectDescriptorBaseModel
+from ga4gh.vrsatile.pydantic.vrs_models import CURIE
+from ga4gh.vrsatile.pydantic.vrsatile_models import ValueObjectDescriptor
 from pydantic import BaseModel, StrictBool, validator
 
 from therapy.version import __version__
@@ -230,12 +229,10 @@ class NamespacePrefix(Enum):
     """Define string constraints for namespace prefixes on concept IDs."""
 
     ATC = "atc"  # Anatomical Therapeutic Chemical Classification System
-    BINDINGDB = "bindingdb"
     CHEBI = "CHEBI"
     CHEMBL = "chembl"
     CHEMIDPLUS = "chemidplus"
     CASREGISTRY = CHEMIDPLUS
-    CHEMSPIDER = "chemspider"
     CVX = "cvx"  # Vaccines Administered
     DRUGBANK = "drugbank"
     DRUGCENTRAL = "drugcentral"
@@ -243,31 +240,22 @@ class NamespacePrefix(Enum):
     DRUGSATFDA_NDA = "drugsatfda.nda"
     HEMONC = "hemonc"
     INCHIKEY = "inchikey"
-    ISO = "iso"
-    IUPHAR = "iuphar"
     IUPHAR_LIGAND = "iuphar.ligand"
     GUIDETOPHARMACOLOGY = IUPHAR_LIGAND
-    KEGGCOMPOUND = "kegg.compound"
-    KEGGDRUG = "kegg.drug"
     MMSL = "mmsl"  # Multum MediSource Lexicon
     MSH = "mesh"  # Medical Subject Headings
-    MTHCMSFRF = "mthcmsfrf"  # CMS Formulary Reference File
     NCIT = "ncit"
     NDC = "ndc"  # National Drug Code
-    PDB = "pdb"
-    PHARMGKB = "pharmgkb.drug"
     PUBCHEMCOMPOUND = "pubchem.compound"
     PUBCHEMSUBSTANCE = "pubchem.substance"
     RXNORM = "rxcui"
     SPL = "spl"  # Structured Product Labeling
-    THERAPEUTICTARGETSDB = "ttd"
     UMLS = "umls"
     UNII = "unii"
     UNIPROT = "uniprot"
     USP = "usp"  # USP Compendial Nomenclature
     VANDF = "vandf"  # Veterans Health Administration National Drug File
     WIKIDATA = "wikidata"
-    ZINC = "zinc"
 
 
 class DataLicenseAttributes(BaseModel):
@@ -405,17 +393,7 @@ class MatchesListed(BaseModel):
             }
 
 
-class ApprovalRatingValue(BaseModel):
-    """VOD Extension class for regulatory approval rating/indication
-    value attributes.
-    """
-
-    approval_ratings: Optional[List[ApprovalRating]]
-    approval_year: Optional[List[str]]
-    has_indication: Optional[List[DiseaseDescriptor]]
-
-
-class TherapyDescriptor(ValueObjectDescriptorBaseModel):
+class TherapyDescriptor(ValueObjectDescriptor):
     """Create therapy descriptor model"""
 
     type: Literal["TherapyDescriptor"] = "TherapyDescriptor"
